==> cappuccino-2.0.x-dev.tar.gz: cappuccino/web/profiles/cappuccino/themes/ino_basetheme/gulpfile.js <==
'use strict';

var gulp          = require('gulp');
var browserSync   = require('browser-sync').create();
var sass          = require('gulp-sass');
var sourcemaps    = require('gulp-sourcemaps');
var globbing      = require('gulp-css-globbing');
var duration      = require('gulp-duration');
var postcss       = require('gulp-postcss');
var autoprefixer  = require('autoprefixer');
var csswring      = require('csswring');
var uglify        = require('gulp-uglify');
var pump          = require('pump');

var paths = {
  app:  '',
  src: 'src',
  dist: 'dist',
  css:  'dist/css',
  js:   'dist/js'
};

gulp.task('browser-sync', function() {
  browserSync.init({
    proxy: "http://URL_LOCAL_SITE"
  });
});

gulp.task('js-dev', function (cb) {
  pump([
      gulp.src(paths.src + '/**/*.js'),
      gulp.dest(paths.dist)
    ],
    cb
  );
});


gulp.task('sass-dev', gulp.series('js-dev', function() {
  var processors = [
    autoprefixer({browsers: ['last 10 versions', 'ie 9']})
  ];

  return gulp.src(paths.src + '/global/styles.scss')
    .pipe(sourcemaps.init())
    .pipe(globbing({ extensions: ['.scss'] }))
    .pipe(sass.sync({includePaths: [
        './../../../../',
        './../../../../../',
      ]}).on('error', function(err) {
      console.error(err.message);
      browserSync.notify(err.message, 3000);
      this.emit('end');
    }))
    .pipe(duration('SASS compilation finished'))
    .pipe(postcss(processors))
    .pipe(duration('postCSS finished'))
    .pipe(sourcemaps.write('../map'))
    .pipe(duration('created sourcemap files'))
    .pipe(gulp.dest(paths.css + '/global'))
    .pipe(browserSync.reload({stream: true}))
    ;
}));

gulp.task('js-prod', function (cb) {
  pump([
      gulp.src(paths.src + '/**/*.js'),
      uglify(),
      gulp.dest(paths.dist)
    ],
    cb
  );
});

gulp.task('sass-prod', gulp.series('js-prod', function () {
  var processors = [
    autoprefixer({browsers: ['last 10 versions', 'ie 9']}),
    csswring
  ];

  return gulp.src(paths.src + '/global/styles.scss')
    .pipe(globbing({ extensions: ['.scss'] }))
    .pipe(sass.sync({includePaths: [
        './../../../../',
        './../../../../../',
      ]}).on('error', sass.logError).on('error', process.exit.bind(process, 1)))
    .pipe(postcss(processors))
    .pipe(gulp.dest(paths.css + '/global'))
  ;
}));

gulp.task('watch', gulp.parallel('sass-dev', 'browser-sync', function() {
  gulp.watch(paths.src + "/**/*", gulp.series('sass-dev')).on('change', browserSync.reload);
  gulp.watch(paths.app + '/*.twig').on('change', browserSync.reload);
  gulp.watch(paths.app + '/*.php').on('change', browserSync.reload);
}));

gulp.task('watch-docker', gulp.series('sass-dev', function() {
  gulp.watch(paths.src + "/**/*", gulp.series('sass-dev'));
}));

/* Default task*/
gulp.task('default', gulp.series('watch'));

==> cappuccino-3.0.x-dev.tar.gz: cappuccino/web/profiles/cappuccino/themes/ino_basetheme/gulpfile.js <==
'use strict';

var gulp          = require('gulp');
var browserSync   = require('browser-sync').create();
var sass          = require('gulp-sass')(require('node-sass'));
var sourcemaps    = require('gulp-sourcemaps');
var globbing      = require('gulp-css-globbing');
var duration      = require('gulp-duration');
var postcss       = require('gulp-postcss');
var autoprefixer  = require('autoprefixer');
var uglify        = require('gulp-uglify');
var pump          = require('pump');

var paths = {
  app:  '',
  src: 'src',
  dist: 'dist',
  css:  'dist/css',
  js:   'dist/js'
};

gulp.task('browser-sync', function() {
  browserSync.init({
    proxy: "http://URL_LOCAL_SITE"
  });
});

gulp.task('js-dev', function (cb) {
  pump([
      gulp.src(paths.src + '/**/*.js'),
      gulp.dest(paths.dist)
    ],
    cb
  );
});

gulp.task('sass-dev', gulp.series('js-dev', function() {
  var processors = [
    autoprefixer()
  ];

  return gulp.src(paths.src + '/global/styles.scss')
    .pipe(sourcemaps.init())
    .pipe(globbing({ extensions: ['.scss'] }))
    .pipe(sass.sync({includePaths: [
        './../../../',
        './../../../../',
        './../../../../../',
      ]}).on('error', function(err) {
      console.error(err.message);
      browserSync.notify(err.message, 3000);
      this.emit('end');
    }))
    .pipe(duration('SASS compilation finished'))
    .pipe(postcss(processors))
    .pipe(duration('postCSS finished'))
    .pipe(sourcemaps.write('../map'))
    .pipe(duration('created sourcemap files'))
    .pipe(gulp.dest(paths.css + '/global'))
    .pipe(browserSync.reload({stream: true}))
    ;
}));

gulp.task('js-prod', function (cb) {
  pump([
      gulp.src(paths.src + '/**/*.js'),
      uglify(),
      gulp.dest(paths.dist)
    ],
    cb
  );
});

gulp.task('sass-prod', gulp.series('js-prod', function () {
  var processors = [
    autoprefixer()
  ];

  return gulp.src(paths.src + '/global/styles.scss')
    .pipe(globbing({ extensions: ['.scss'] }))
    .pipe(sass.sync({includePaths: [
        './../../../',
        './../../../../',
        './../../../../../',
      ],
      outputStyle: "compressed",
    }).on('error', sass.logError).on('error', process.exit.bind(process, 1)))
    .pipe(postcss(processors))
    .pipe(gulp.dest(paths.css + '/global'))
    ;
}));

gulp.task('watch', gulp.parallel('sass-dev', 'browser-sync', function() {
  gulp.watch(paths.src + "/**/*", gulp.series('sass-dev')).on('change', browserSync.reload);
  gulp.watch(paths.app + '/*.twig').on('change', browserSync.reload);
  gulp.watch(paths.app + '/*.php').on('change', browserSync.reload);
}));

gulp.task('watch-docker', gulp.series('sass-dev', function() {
  gulp.watch(paths.src + "/**/*", gulp.series('sass-dev'));
}));

/* Default task*/
gulp.task('default', gulp.series('watch'));
